Package: editrules
Maintainer: Edwin de Jonge <edwindjonge@gmail.com>
License: GPL-3
Title: Parsing, Applying, and Manipulating Data Cleaning Rules
LazyData: no
Type: Package
LazyLoad: yes
Authors@R: c(person(given = "Edwin",
                        family = "de Jonge",
                        role = c("aut", "cre"),
                        email = "edwindjonge@gmail.com",
                        comment=c(ORCID="0000-0002-6580-4718")
              ),
                 person(given = "Mark",
                        family = "van der Loo",
                        role = "aut"))
Description: Please note: active development has moved to packages 'validate'
    and 'errorlocate'. Facilitates reading and manipulating (multivariate) data
    restrictions (edit rules) on numerical and categorical data. Rules can be
    defined with common R syntax and parsed to an internal (matrix-like format).
    Rules can be manipulated with variable elimination and value substitution
    methods, allowing for feasibility checks and more. Data can be tested against
    the rules and erroneous fields can be found based on Fellegi and Holt's
    generalized principle. Rules dependencies can be visualized with using the
    'igraph' package. 
Version: 2.9.6
Depends: R (>= 2.12.0), igraph
Imports: lpSolveAPI
Suggests: testthat
URL: https://github.com/data-cleaning/editrules
BugReports: https://github.com/data-cleaning/editrules/issues
Collate: 'adjacency.R' 'as.igraph.R' 'editset.R' 'editarray.R'
        'editmatrix.R' 'as.matrix.R' 'backtracker.R' 'blocks.R' 'c.R'
        'cateditmatrix.R' 'checkDatamodel.R' 'checkRows.R' 'contains.R'
        'disjunct.R' 'duplicated.R' 'echelon.R' 'editAttr.R'
        'editarrayAttr.R' 'editfile.R' 'editmatrixAttr.R'
        'editrules-data.R' 'eliminate.R' 'errorLocalizer.R'
        'errorLocalizer_mip.R' 'errorLocation.R' 'expandEdits.R'
        'generateEdits.R' 'getH.R' 'getUpperBounds.R' 'getVars.R'
        'is.R' 'isFeasible.R' 'isObviouslyInfeasible.R'
        'isObviouslyRedundant.R' 'isSubset.R' 'list2env.R'
        'localizeErrors.R' 'mip.R' 'parseCat.R' 'parseEdits.R'
        'parseMix.R' 'parseNum.R' 'perturbWeights.R' 'pkg.R' 'plot.R'
        'plot_errorLocation.R' 'print.R' 'reduce.R' 'removeRedundant.R'
        'softEdits.R' 'str.R' 'subsetting.R' 'substValue.R' 'summary.R'
        'violatedEdits.R' 'writeELAsMip.R' 'zzz.R'
RoxygenNote: 7.3.3
Encoding: UTF-8
NeedsCompilation: no
Packaged: 2025-11-28 11:44:51 UTC; edwin
Author: Edwin de Jonge [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-6580-4718>),
  Mark van der Loo [aut]
Repository: CRAN
Date/Publication: 2025-11-28 12:10:02 UTC
Built: R 4.6.0; ; 2026-04-27 16:10:29 UTC; unix
