# Generated by roxygen2: do not edit by hand

S3method("%+%","NULL")
S3method("%+%",errorLocation)
S3method("[",editarray)
S3method("[",editlist)
S3method("[",editmatrix)
S3method("[",editset)
S3method(adjacency,editarray)
S3method(adjacency,editmatrix)
S3method(adjacency,editset)
S3method(as.character,editarray)
S3method(as.character,editmatrix)
S3method(as.character,editset)
S3method(as.data.frame,editarray)
S3method(as.data.frame,editmatrix)
S3method(as.data.frame,editset)
S3method(as.data.frame,violatedEdits)
S3method(as.expression,editarray)
S3method(as.expression,editmatrix)
S3method(as.igraph,editarray)
S3method(as.igraph,editmatrix)
S3method(as.igraph,editset)
S3method(as.matrix,editarray)
S3method(as.matrix,editmatrix)
S3method(c,editarray)
S3method(c,editmatrix)
S3method(c,editset)
S3method(checkDatamodel,editarray)
S3method(checkDatamodel,editmatrix)
S3method(checkDatamodel,editset)
S3method(checkRows,character)
S3method(checkRows,data.frame)
S3method(checkRows,editmatrix)
S3method(contains,boolmat)
S3method(contains,cateditmatrix)
S3method(contains,editarray)
S3method(contains,editmatrix)
S3method(contains,editset)
S3method(contains,matrix)
S3method(duplicated,editarray)
S3method(duplicated,editmatrix)
S3method(echelon,editmatrix)
S3method(echelon,editset)
S3method(echelon,matrix)
S3method(eliminate,editarray)
S3method(eliminate,editlist)
S3method(eliminate,editmatrix)
S3method(eliminate,editset)
S3method(errorLocalizer,editarray)
S3method(errorLocalizer,editlist)
S3method(errorLocalizer,editmatrix)
S3method(errorLocalizer,editset)
S3method(getVars,"NULL")
S3method(getVars,cateditmatrix)
S3method(getVars,editarray)
S3method(getVars,editlist)
S3method(getVars,editmatrix)
S3method(getVars,editset)
S3method(impliedValues,editmatrix)
S3method(isObviouslyInfeasible,"NULL")
S3method(isObviouslyInfeasible,editarray)
S3method(isObviouslyInfeasible,editenv)
S3method(isObviouslyInfeasible,editlist)
S3method(isObviouslyInfeasible,editmatrix)
S3method(isObviouslyInfeasible,editset)
S3method(isObviouslyRedundant,editarray)
S3method(isObviouslyRedundant,editenv)
S3method(isObviouslyRedundant,editlist)
S3method(isObviouslyRedundant,editmatrix)
S3method(isObviouslyRedundant,editset)
S3method(isObviouslyRedundant,matrix)
S3method(plot,editarray)
S3method(plot,editmatrix)
S3method(plot,editset)
S3method(plot,errorLocation)
S3method(plot,violatedEdits)
S3method(print,backtracker)
S3method(print,cateditmatrix)
S3method(print,editarray)
S3method(print,editlist)
S3method(print,editmatrix)
S3method(print,editset)
S3method(print,editsummary)
S3method(print,errorLocation)
S3method(print,locationsummary)
S3method(print,violatedEdits)
S3method(reduce,editarray)
S3method(reduce,editmatrix)
S3method(reduce,editset)
S3method(str,editarray)
S3method(str,editmatrix)
S3method(substValue,editarray)
S3method(substValue,editenv)
S3method(substValue,editlist)
S3method(substValue,editmatrix)
S3method(substValue,editset)
S3method(summary,editarray)
S3method(summary,editmatrix)
S3method(summary,editset)
S3method(summary,errorLocation)
S3method(summary,violatedEdits)
S3method(violatedEdits,character)
S3method(violatedEdits,data.frame)
S3method(violatedEdits,editarray)
S3method(violatedEdits,editmatrix)
S3method(violatedEdits,editset)
export(adjacency)
export(as.editmatrix)
export(as.editset)
export(as.lp.mip)
export(as.mip)
export(backtracker)
export(blockIndex)
export(blocks)
export(checkDatamodel)
export(choicepoint)
export(condition)
export(contains)
export(datamodel)
export(disjunct)
export(echelon)
export(editType)
export(editarray)
export(editfile)
export(editmatrix)
export(editnames)
export(editset)
export(eliminate)
export(errorLocalizer)
export(errorLocalizer_mip)
export(generateEdits)
export(getA)
export(getAb)
export(getH)
export(getOps)
export(getVars)
export(getb)
export(geth)
export(impliedValues)
export(is.editarray)
export(is.editmatrix)
export(is.editset)
export(isFeasible)
export(isNormalized)
export(isObviouslyInfeasible)
export(isObviouslyRedundant)
export(isSubset)
export(localizeErrors)
export(nedits)
export(normalize)
export(reduce)
export(separate)
export(substValue)
export(violatedEdits)
import(lpSolveAPI)
importFrom(graphics,axis)
importFrom(graphics,barplot)
importFrom(graphics,grid)
importFrom(graphics,lines)
importFrom(graphics,mtext)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(igraph,as.igraph)
importFrom(lpSolveAPI,make.lp)
importFrom(lpSolveAPI,set.column)
importFrom(stats,density)
importFrom(stats,dist)
importFrom(stats,quantile)
importFrom(stats,runif)
importFrom(utils,flush.console)
importFrom(utils,ls.str)
importFrom(utils,stack)
importFrom(utils,str)
